<?php
$apptsPending = [
    'status' => $pro->getAppointmentsPendingStatusChangeAck(),
    'decision' => $pro->getAppointmentsPendingDecisionAck(),
    // 'time' => $pro->getAppointmentsPendingTimeChangeAck()
];
?>

<div id="mcp-dashboard-notifications">

    <div class="card mb-4">
        <div class="card-header pl-2">
            <div class="d-flex justify-content-between">
                <strong>
                    Appointment Status Changes
                </strong>
                <button type="button" class="d-none btn btn-sm btn-primary" data-action="acknowledgeStatusAsAppointmentPro" submit-ack-appts>Ack. Selected (<span></span>)</button>
            </div>            
        </div>
        <div class="card-body p-0">
            @if(!count($apptsPending['status']))
                <div class="p-2">
                    No new changes
                </div>
            @endif
            @if(count($apptsPending['status']))
                <table class="table table-sm table-striped">
                    <thead>
                    <tr>
                        <th><input type="checkbox" select-all-appts data-target="#apptsStatusChanges" /></th>
                        <th>Patient</th>
                        <th>Time</th>
                        <th>Memo</th>
                        <th>Status</th>
                        <th></th>
                    </tr>
                    </thead>
                    <tbody id="apptsStatusChanges">
                    @foreach($apptsPending['status'] as $appt)
                        <tr discardable-container>
                            <td><input type="checkbox" name="uids[]" value="{{ $appt->uid }}" select-appt /></td>
                            <td>
                                <a class="d-block"
                                   href="/patients/view/{{$appt->client->uid}}">{{$appt->client->displayName()}}</a>
                            </td>
                            <td>
                                {{friendlier_date_time($appt->start_time)}}
                            </td>
                            <td>
                                @if($appt->status_memo)
                                    <div class="text-secondary text-sm">{{$appt->status_memo}}</div>
                                @endif
                            </td>
                            <td>
                                <span class="font-weight-bold text-secondary">{{$appt->status}}</span>
                            </td>
                            <td>
                                <form url="/api/appointment/acknowledgeStatusAsAppointmentPro" discardable>
                                    <input type="hidden" name="uid" value="{{$appt->uid}}">
                                    <input type="hidden" name="currentStatus" value="{{$appt->status}}">
                                    @if($appt->status_memo !== null)
                                        <input type="hidden" name="currentStatusMemo" value="{{$appt->status_memo}}">
                                    @endif
                                    <input type="hidden" name="currentRawDate" value="{{$appt->raw_date}}">
                                    <input type="hidden" name="currentRawStartTime" value="{{$appt->raw_start_time}}">
                                    <input type="hidden" name="currentRawEndTime" value="{{$appt->raw_end_time}}">
                                    <input type="hidden" name="currentTimezone" value="{{$appt->timezone}}">
                                    <button submit class="bg-transparent border-0 p-0 text-primary">Ack.</button>
                                </form>
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                <div class="m-2">
                    {{ $apptsPending['status']->withQueryString()->links() }}
                </div>
            @endif
        </div>
    </div>

    <div class="card mb-4">
        <div class="card-header pl-2">
            <div class="d-flex justify-content-between">
                <strong>
                    Appointment Confirmation Changes
                </strong>
                <button type="button" class="d-none btn btn-sm btn-primary" data-action="acknowledgeDecisionAsAppointmentPro" submit-ack-appts>Ack. Selected (<span></span>)</button>
            </div>
        </div>
        <div class="card-body p-0">
            @if(!count($apptsPending['decision']))
                <div class="p-2">
                    No new changes
                </div>
            @endif
            @if(count($apptsPending['decision']))
                <table class="table table-sm table-striped">
                    <thead>
                    <tr>
                        <th><input type="checkbox" select-all-appts data-target="#apptsConfirmationChanges" /></th>
                        <th>Patient</th>
                        <th>Time</th>
                        <th>Status</th>
                        <th></th>
                    </tr>
                    </thead>
                    <tbody id="apptsConfirmationChanges">
                    @foreach($apptsPending['decision'] as $appt)
                        <tr discardable-container>
                            <td><input type="checkbox" name="uids[]" value="{{ $appt->uid }}" select-appt /></td>
                            <td>
                                <a class="d-block"
                                   href="/patients/view/{{$appt->client->uid}}">{{$appt->client->displayName()}}</a>
                            </td>
                            <td>{{friendlier_date_time($appt->start_time)}}</td>
                            <td>{{$appt->latestConfirmationDecision->decision_enum}}</td>
                            <td>
                                <form url="/api/appointment/acknowledgeDecisionAsAppointmentPro" discardable>
                                    <input type="hidden" name="uid" value="{{$appt->uid}}">
                                    <button submit class="bg-transparent border-0 p-0 text-primary">Ack.</button>
                                </form>
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                <div class="m-2">
                    {{ $apptsPending['decision']->withQueryString()->links() }}
                </div>
            @endif
        </div>
    </div>

</div>

<script>
    (function($){
        const BulkAckAppointments = {
            handleOnCheck: function(container){
                const selectedAppts = container.find('input[type=checkbox]:checked');
                    const button = $(container).closest('.card').find('.card-header').find('button');
                    if(selectedAppts.length){
                        button.find('span').text(selectedAppts.length);
                        button.removeClass('d-none');
                    }else{
                        button.addClass('d-none');
                    }
            },
            onCheck: function(){
                var self = this;
                $('[select-appt]').click(function(evt){
                    const container = $(evt.currentTarget).closest('tbody');
                    self.handleOnCheck(container);
                });
            },
            onCheckAll: function(){
                var self = this;
                $('[select-all-appts]').click(function(evt){
                    const isChecked = evt.currentTarget.checked ? true:false;

                    const containerTargetRef = $(evt.currentTarget).data('target');
                    const container = $(containerTargetRef);
                    container.find('input[type=checkbox]').prop('checked', isChecked);
                    self.handleOnCheck(container);
                });
            },
            onSubmit: function(){
                var self = this;
                $('[submit-ack-appts]').click(function(evt){
                    const action = $(evt.currentTarget).data('action');
                    const container = $(evt.currentTarget).closest('.card').find('tbody');
                    const checkedInputs = container.find('[select-appt]:checked');
                    console.log({checkedInputs});
                    const UIDS = [];
                    $.each(checkedInputs, function(index, input){
                        const value  = input.value;
                        UIDS.push(value);
                    });

                    $.post('/acknowledge-as-appointment-pro', {uids: UIDS, action: action}, function(response){
                        if(response.success){
                            toastr.success();
                            location.reload();
                        }else{
                            toastr.error(response.message);
                            location.reload();
                        }
                    }, 'json');

                });
            },
            init: function(){
                this.onCheck();
                this.onCheckAll();
                this.onSubmit();
            }
        };
        BulkAckAppointments.init();
    })(jQuery);
</script>