<h3 style="font-weight: bolder; font-size: 18px; line-height:18px; margin:0px;" class="mb-3"><b>Remote Monitoring:</b>
</h3>
<table class="table table-sm table-bordered mt-2 mb-0">
    <thead>
    <tr>
        <th class="px-1 text-nowrap"><b>Date</b></th>
        <th class="px-1"><b>Measurement</b></th>
        <th class="px-1"><b>Type</b></th>
        <th class="px-1"><b>Time</b></th>
        <th class="px-1"><b>Interaction</b></th>
        <th class="px-4 w-100"><b>Comments</b></th>
    </tr>
    </thead>
    <tbody>
    @php
        $measurementsInCareMonth = $patient->measurementsInCareMonth($careMonth);
        $plottableMeasurements = [];

        $printableMeasurements = [];

        foreach($measurementsInCareMonth as $measurement){
            if($measurementType && stripos($measurement->label, $measurementType) === false ){
                continue;
            }
            if (!empty($measurement->label) && !in_array($measurement->label, ['SBP', 'DBP']) && !$measurement->is_cellular_zero){

                $date = friendly_date($measurement->effective_date, true, 'EASTERN');
                if(!isset($printableMeasurements[$date])){
                    $printableMeasurements[$date] = [
                        'measurements' => [],
                        'times' => [],
                        'types' => [],
                        'interaction' => '',
                        'notes' => []
                    ];
                }

                $value = null;
                $type = null;
                $time = null;

                if ($measurement->ts){
                    $timestampInSec = floor($measurement->ts / 1000);
                    $time = friendly_date_time_short_with_tz_from_timestamp($timestampInSec, 'EASTERN');
                }else{
                    $time = friendly_date_time_short_with_tz($measurement->effective_date, true, 'EASTERN');
                }

                $time = friendly_time($time);

                if ($measurement->is_cellular_zero){
                    $value = '<i class="font-size-11 fa fa-rss"></i>';
                }elseif($measurement->label === 'BP'){
                    $value = $measurement->sbp_mm_hg. '/'.$measurement->dbp_mm_hg .'mmHg';
                    $type = 'BP';
                }elseif($measurement->label === 'Wt. (lbs.)'){
                    $value = round(floatval($measurement->numeric_value), 2). 'lbs';
                    $type = 'Weight';
                }else {
                    $value = $measurement->value;
                }

                $printableMeasurements[$date]['values'][] = $value;
                $printableMeasurements[$date]['types'][] = $type;
                $printableMeasurements[$date]['times'][] = $time;

                $notes = [];
                foreach($careMonth->entries as $entry){
                    if(friendly_date($entry->effective_date) == friendly_date($measurement->effective_date)){
                        $note = [];
                        $note['content'] = $entry->content_text;
                        $note['duration'] = $entry->time_in_seconds/60;
                        $note['timestamp'] = friendly_date_time($entry->created_at);
                         if($entry->pro){
                            if($entry->pro->is_hcp){
                                $note['author'] = $entry->pro->displayName();
                            }else{
                                $note['author'] = 'Medical Staff';
                            }
                        }
                        $notes[] = $note;
                    }

                    $printableMeasurements[$date]['notes'] = $notes;

                }

                $interaction = null;
                //$found = false;
                 foreach($careMonth->entries as $entry){
                     if(friendly_date($entry->effective_date) == friendly_date($measurement->effective_date) && $entry->did_pro_interact_with_client_about_rm ){
                        if(str_contains($entry->content_text, 'text')){
                            $interaction = 'Text';
                        }else{
                            $interaction = 'Audio call';
                        }
                    }
                }
                  $printableMeasurements[$date]['interaction'] = $interaction;
            }
        }

    @endphp


    @foreach ($printableMeasurements as $date => $measurement)
        <tr>
            <td class="px-2 text-nowrap">
                {{$date}}
                EST
            </td>
            <td class="px-1 text-nowrap">
                @foreach($measurement['values'] as $value)
                    <div class="text-nowrap">
                        {{$value}}
                    </div>
                @endforeach
            </td>
            <td class="px-1 text-nowrap">
                @foreach($measurement['types'] as $type)
                    <div class="text-nowrap">
                        {{$type}}
                    </div>
                @endforeach
            </td>
            <td class="px-1 text-nowrap">
                @foreach($measurement['times'] as $time)
                    <div class="text-nowrap">
                        {{$time}}
                    </div>
                @endforeach
            </td>
            <td class="text-nowrap">
                <div class="">
                    {{$measurement['interaction']}}
                </div>
            </td>
            <td class="px-4">
                <div class="mb-2">
                    @foreach($measurement['notes'] as $note)

                        <div class="d-flex align-items-start">
                            <span class="mr-2">{{$note['duration']}}m: </span>
                            <div>{!!  $note['content']  !!}</div>
                        </div>
                        <div class="d-flex justify-content-end ">
                            <div class="mr-1">
                                <b>
                                    {{$note['author']}}
                                </b>
                            </div>
                            <div>{{$note['timestamp']}}</div>
                        </div>
                        @if (!$loop->last)
                            <hr>
                        @endif
                    @endforeach
                </div>
            </td>
        </tr>
    @endforeach

    </tbody>
</table>
