<?php

use App\Models\Point;

/** @var \App\Models\Client $patient */

$points = Point::getPlanPointsOfCategory($patient, 'MEDICATION', $note);
$tracker = Point::getGlobalSingletonOfCategory($patient, 'NO_KNOWN_TRACKER');
$numRelevant = 0;
$numVisible = 0;
$plural = 'Medications';
?>

<?php if($tracker && @($tracker->data->no_known_medications)): ?>
    <div class="text-secondary"><span>-</span></div>
<?php endif; ?>
<?php if(!$tracker || !@($tracker->data->no_known_medications)): ?>
<?php if (!count($points)): ?>
    <div class="text-secondary">-</div>
<?php else: ?>
    <table class="table table-bordered table-xs table-cage mb-0">
        <?php $j = 0; foreach ($points as $point): $j++; ?>
        <?php if($point->is_removed && $point->is_removed_due_to_entry_error) continue; ?>
        <?php $rel = $point->relevanceToNote($note); ?>
        <?php $plan = $point->lastChildPlan; ?>
        <?php if($plan && @($plan->data)) $plan->data = json_decode($plan->data); ?>
        <?php $numVisible++; ?>
        <tr>
            <td class="width-40px px-2 {{ $rel ? 'font-weight-bold text-info':'' }}">
                @if($rel)
                    <?php $numRelevant++; ?>
                    {{ $j }}.*
                @else
                    {{ $j }}.
                @endif
            </td>
            <td class="px-2 width-300px">
                <div class="font-weight-bold <?= $point->is_removed ? 'strike-through' : '' ?>">
                    <?= !!@($point->data->name) ? @($point->data->name) : '-' ?>
                </div>
            </td>
            <td class="px-2 width-300px">
                <div>
                    <?php if(!!$plan): ?>
                    <div class="pl-3 mt-1 d-flex align-items-baseline">
                        <span>{!! $plan->data->value !!}</span>
                    </div>
                    <?php endif; ?>
                </div>
                <div class="d-flex align-items-baseline">                
                    <?php if ($point->is_removed): ?>
                        @if($point->removal_reason_category === 'DURING_VISIT')
                            <span class="ml-2 text-sm text-secondary">Removed during visit</span>
                        @elseif($point->removal_reason_category === 'ON_INTAKE')
                            <span class="ml-2 text-sm text-secondary">Historic</span>
                        @endif
                    <?php elseif ($point->added_in_note_id === $note->id): ?>
                        <?php if ($point->addition_reason_category === 'DURING_VISIT'): ?>
                            <span class="ml-2 text-sm text-success">* Prescribed during visit</span>
                        <?php else: ?>
                            <span class="ml-2 text-sm text-info">Added on intake</span>
                        <?php endif;?>
                    <?php endif; ?>
                </div>
            </td>
            <td></td>
        </tr>
    <?php endforeach; ?>
    </table>
    @if(!$numVisible)
        <div class="d-flex align-items-baseline mr-1">
            <span class="text-secondary">-</span>
        </div>
    @endif
<?php endif; ?>
<?php endif; ?>
