@extends ($layout)
@section('survey-header')
<span>Hi {{ @$entity->displayName() }}</span>
@endsection
@section('survey-content')
  <form id="surveyForm" action="{{ @$survey->access_key ? route('view-survey-form-submit', @$survey->access_key) : '' }}" method="POST" v-cloak>
    @if(!isset($preview))
      <input type="hidden" name="data" :value="JSON.stringify(form)" />
      @csrf
    @endif

    @if(@$survey->is_completed)
      <div class="alert alert-success p-1 rounded-0">This survey is marked as completed!</div>
      <fieldset disabled>
    @endif
    
    <div><?= $survey->surveyhtml ?></div>

    @if(@$survey->is_completed)
      </fieldset>
    @endif
    
    @if(!isset($preview))
      <div class="row">      
          <div class="col-md-12">
            @if(@$survey->is_completed)
              <input type="hidden" name="undo_mark_as_completed" value="1" />
              <button class="btn btn-sm btn-danger px-5 py-2">Undo mark as completed</button>
            @else
              <input type="hidden" name="mark_as_completed" value="1" />
              <button class="btn btn-sm btn-primary px-5 py-2">Mark as completed</button>
            @endif
          </div>
      </div>
    @endif
  </form>

<script>
  var surveyFormComponent = new Vue({
    el: '#surveyForm',
    data: {
      socketSessionID: "{{ time() }}",
      surveyAccessKey: "{{ @$survey->access_key }}",

      form: <?= json_encode(json_decode($survey->survey_data ?? '{}')) ?>,
      socketIo: null,
      submitting: false,
      loading: false,
    },
    methods: {
      onFormFieldChange: function(){
        var self = this;
        self.socketIo = io("{{ config('app.socketIoUrl') }}");
        self.watchInputFields();
      },
      watchInputFields: function(){
        var self = this;
        var form = $('#surveyForm');
        form.find('select, textarea').off('change');
        form.find('input, select, textarea').on('change', function(){
          self.autosaveChanges();
          return;
        });

      },
      autosaveChanges: function(){
        var self = this;
        if(self.submitting) return;
        self.submitting = true;
        var url = "{{ @$survey->access_key ? route('view-survey-form-auto-submit', @$survey->access_key) : '' }}";
        $.post(url, { dataJson: JSON.stringify(self.form) }, function(response){
          self.submitting = false;
          if(response.success){
            self.socketIo.emit('SURVEY_DATA_CHANGED_BY_SESSION', {socketSessionID: self.socketSessionID, surveyAccessKey: self.surveyAccessKey});
          }else{
            toastr.error(response.message);
          }
        }, 'json');
      },
      onSurveyDataChange: function(){
        var self = this;
        self.socketIo.on('UPDATE_SURVEY_DATA_CHANGED_BY_SESSION', (data) => {
          if(data.socketSessionID === self.socketSessionID) return;
          if(data.surveyAccessKey !== self.surveyAccessKey) return;
          self.updateUi();
        });
      },
      updateUi: function(){
        var self = this;
        if(self.loading) return;
        self.loading = true;
        var url = "{{ @$survey->access_key ? route('view-survey-form-get-data', @$survey->access_key) : '' }}";
        $.get(url, {}, function(response){
          self.loading = false;
          if(response.success){
            const data = JSON.parse(response.data.survey_data);
            self.form = data;
          }
        }, 'json');

      },
      init: function(){
        this.onFormFieldChange();
        this.onSurveyDataChange();
      }
    },
    mounted: function(){
      this.init();
    },
    updated: function(){
      var self = this;
      self.$nextTick(function(){
       self.watchInputFields();
      });
    }
  });
</script>


@endsection
